<?php declare(strict_types=1);

namespace App\Entity;

use App\Repository\MenuItemRepository;
use DateTimeImmutable;
use Doctrine\ORM\Mapping as ORM;
use Symfony\Bridge\Doctrine\IdGenerator\UlidGenerator;
use Symfony\Bridge\Doctrine\Types\UlidType;
use Symfony\Component\Uid\Ulid;

#[ORM\Entity(repositoryClass: MenuItemRepository::class)]
class MenuItem
{
    #[ORM\Id]
    #[ORM\GeneratedValue(strategy: 'CUSTOM')]
    #[ORM\Column(type: UlidType::NAME, unique: true)]
    #[ORM\CustomIdGenerator(class: UlidGenerator::class)]
    private Ulid|null $id = null;

    #[ORM\Column(length: 255)]
    private string|null $name = null;

    #[ORM\ManyToOne(inversedBy: 'menuItems')]
    #[ORM\JoinColumn(nullable: false)]
    private FoodVendor|null $foodVendor = null;

    #[ORM\Column(nullable: true)]
    private DateTimeImmutable|null $deletedAt = null;

    public function getId(): Ulid|null
    {
        return $this->id;
    }

    public function getName(): string|null
    {
        return $this->name;
    }

    public function setName(string $name): static
    {
        $this->name = $name;

        return $this;
    }

    public function getFoodVendor(): FoodVendor|null
    {
        return $this->foodVendor;
    }

    public function setFoodVendor(FoodVendor|null $foodVendor): static
    {
        $this->foodVendor = $foodVendor;

        return $this;
    }

    public function isDeleted(): bool
    {
        return $this->getDeletedAt() instanceof DateTimeImmutable;
    }

    public function delete(): static
    {
        $this->setDeletedAt();
        return $this;
    }

    public function getDeletedAt(): DateTimeImmutable|null
    {
        return $this->deletedAt;
    }

    public function setDeletedAt(DateTimeImmutable|null $deletedAt = new DateTimeImmutable): static
    {
        $this->deletedAt = $deletedAt;

        return $this;
    }
}
